#include <MoleGraph.h>
#include <Wire.h>
#include "cactus_io_BME280_I2C.h"

#define SEALEVELPRESSURE_HPA (1013.25)

//timer
unsigned long   previousTimer1 = 0;   
unsigned long   intervalTimer1 = 20; //20 ms = 50 Hz

float pressureHP, temperatureC, humidity, altitude, dewpoint;

// Create BME280 object
//BME280_I2C bme; // I2C using address 0x77
BME280_I2C bme(0x76); // I2C using address 0x76

MoleGraph moleGraph;

void UpdateGraphChannels(void)
{
  moleGraph.SetChannelValue(1, pressureHP);
  moleGraph.SetChannelValue(2, temperatureC);
  moleGraph.SetChannelValue(3, humidity);
  moleGraph.SetChannelValue(4, altitude);
  moleGraph.SetChannelValue(5, dewpoint);
  //moleGraph.SetChannelValue(6, 0.0);
  //moleGraph.SetChannelValue(7, 0.0);
  //moleGraph.SetChannelValue(8, 0.0);
}
void MeasurementStartedCallback(void)
{
  digitalWrite(13, HIGH);
}
void MeasurementStoppedCallback(void)
{
  digitalWrite(13, LOW);
}
void MeasurementPausedCallback(void)
{
  digitalWrite(13, LOW);
}
void MeasurementContinuedCallback(void)
{
  digitalWrite(13, HIGH);
}


void setup()
{
  moleGraph.Setup();
  moleGraph.SetSendingCallback(&UpdateGraphChannels);
  moleGraph.SetMeasurementStartedCallback(&MeasurementStartedCallback);
  moleGraph.SetMeasurementStoppedCallback(&MeasurementStoppedCallback);
  moleGraph.SetMeasurementPausedCallback(&MeasurementPausedCallback);
  moleGraph.SetMeasurementContinuedCallback(&MeasurementContinuedCallback);
  pinMode(13, OUTPUT);
  
  //BME280 settings
  bme.begin();
  bme.setTempCal(-2);// Temp was reading high so subtract 2 degree
}

void loop()
{
  //run my timer
  unsigned long currentTimer1 = millis();
  
  moleGraph.CheckInput();
  if(currentTimer1 - previousTimer1 > intervalTimer1) {
      /* Get a new sensor val */             
      bme.readSensor();
      
      pressureHP = bme.getPressure_HP();
      temperatureC = bme.getTemperature_C();
      humidity = bme.getHumidity();
      altitude = calcAltitude(SEALEVELPRESSURE_HPA);      
      dewpoint = calcDewPoint();
      
      previousTimer1 = currentTimer1;
  }   
}

float calcAltitude(float seaLevel)
{
    float atmospheric = pressureHP / 100.0F;
    return 44330.0 * (1.0 - pow(atmospheric / seaLevel, 0.1903));
}

float calcDewPoint()
{
    float value = 243.04 * (log(humidity/100.0) + ((17.625 * temperatureC)/(243.04 + temperatureC)))/(17.625 - log(humidity/100.0) - ((17.625 * temperatureC)/(243.04 + temperatureC)));
    return value;
}  

